Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3922)

Unified Diff: chrome/installer/util/auto_launch_util.h

Issue 9972012: Resolve the conflict that auto-launch has with the background mode feature (part 1). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/installer/util/auto_launch_util.h
===================================================================
--- chrome/installer/util/auto_launch_util.h (revision 132169)
+++ chrome/installer/util/auto_launch_util.h (working copy)
@@ -15,26 +15,54 @@
namespace auto_launch_util {
// Returns whether the Chrome executable specified in |application_path| is set
-// to auto-launch at computer startup. NOTE: |application_path| is optional and
-// should be blank in most cases (as it will default to the application path of
-// the current executable). |profile_directory| is the name of the directory
-// (leaf, not the full path) that contains the profile that should be opened at
-// computer startup.
-bool WillLaunchAtLogin(const FilePath& application_path,
- const string16& profile_directory);
+// to auto-launch at computer startup with a given |command_line_switch|.
+// NOTE: |application_path| is optional and should be blank in most cases (as
+// it will default to the application path of the current executable).
+// |profile_directory| is the name of the directory (leaf, not the full path)
+// that contains the profile that should be opened at computer startup.
+// |command_line_switch| is the switch we are optionally interested in and, if
+// not blank, must be present for the function to return true.
Andrew T Wilson (Slow) 2012/04/16 22:57:33 Not sure what the behavior is if command_line_swit
Finnur 2012/04/17 12:27:45 Correct. That function is private now but I'll upd
+bool WillLaunchAtLoginWithSwitch(const FilePath& application_path,
+ const string16& profile_directory,
+ const std::string& command_line_switch);
-// Configures whether the Chrome executable should auto-launch at computer
-// startup. |application_path| is needed when |auto_launch| is true AND when
-// the caller is not the process being set to auto-launch, ie. the installer.
-// This is because |application_path|, if left blank, defaults to the
-// application path of the current executable. If |auto_launch| is true, then it
-// will auto-launch, otherwise it will be configured not to. |profile_directory|
-// is the name of the directory (leaf, not the full path) that contains the
-// profile that should be opened at computer startup.
-void SetWillLaunchAtLogin(bool auto_launch,
- const FilePath& application_path,
- const string16& profile_directory);
+// Disables all auto-start features. |profile_directory| is the name of the
+// directory (leaf, not the full path) that contains the profile that was set
+// to be opened at computer startup.
+void DisableAllAutostartFeatures(const string16& profile_directory);
+// Configures Chrome to auto-launch at computer startup and show a window.
+// |application_path| is needed when one when the caller is not the process
Andrew T Wilson (Slow) 2012/04/16 22:57:33 remove "when one"
+// being set to auto-launch, ie. the installer. This is because
+// |application_path|, if left blank, defaults to the application path of the
+// current executable.
+// |profile_directory| is the name of the directory (leaf, not the full path)
+// that contains the profile that should be opened at computer startup.
+void EnableAutoStartAtLogin(const FilePath& application_path,
+ const string16& profile_directory);
+// Disables autostarting Chrome at computer startup. |profile_directory| is the
grt (UTC plus 2) 2012/04/16 19:43:58 nit: insert newline before comment
+// name of the directory (leaf, not the full path) that contains the profile
+// that was set to be opened at computer startup.
+void DisableAutoStartAtLogin(const string16& profile_directory);
+
+// Enables Chrome to start in the background at computer startup (without a
+// window being shown, except if EnableAutoStartAtLogin has been called).
+// In short, EnableBackgroundModeAtLogin is the no-window version of calling
+// EnableAutoStartAtLogin). If both are called, the no-window setting is
+// ignored.
+// |application_path| is needed when one when the caller is not the process
+// being set to auto-launch, ie. the installer. This is because
+// |application_path|, if left blank, defaults to the application path of the
+// current executable.
+// |profile_directory| is the name of the directory (leaf, not the full path)
+// that contains the profile that should be opened at computer startup.
+void EnableBackgroundModeAtLogin(const FilePath& application_path,
Andrew T Wilson (Slow) 2012/04/16 22:57:33 I don't think we need the profile_directory for th
+ const string16& profile_directory);
+// Disables autostarting Chrome in background mode at computer startup.
grt (UTC plus 2) 2012/04/16 19:43:58 nit: insert newline before comment
+// |profile_directory| is the name of the directory (leaf, not the full path)
+// that contains the profile that was set to be opened at computer startup.
+void DisableBackgroundModeAtLogin(const string16& profile_directory);
Andrew T Wilson (Slow) 2012/04/16 22:57:33 Likewise, this shouldn't need to take a path (see
+
} // namespace auto_launch_util
#endif // CHROME_INSTALLER_UTIL_AUTO_LAUNCH_UTIL_H_

Powered by Google App Engine
This is Rietveld 408576698